# History

## 0.1.0 - 2019-06-24

First Release.

This is a slightly cleaned up version of the software used to generate the results
explained in [The Machine Learning Bazaar Paper](https://arxiv.org/pdf/1905.08942.pdf)
